OC.L10N.register(
    "files_external",
    {
    "Step 1 failed. Exception: %s" : "1 Urratsak huts egin du. Salbuespena: %s",
    "Step 2 failed. Exception: %s" : "2 Urratsak huts egin du. Salbuespena: %s",
    "External storage" : "Kanpoko biltegiratzea",
    "Personal" : "Pertsonala",
    "System" : "Sistema",
    "Grant access" : "Baimendu sarrera",
    "All users. Type to select user or group." : "Erabiltzaile guztiak. Idatzi erabiltzaile edo taldea hautatzeko.",
    "(group)" : "(taldea)",
    "Saved" : "Gordeta",
    "Username" : "Erabiltzaile izena",
    "Password" : "Pasahitza",
    "Save" : "Gorde",
    "App key" : "Aplikazio gakoa",
    "App secret" : "App sekretua",
    "Client ID" : "Bezero ID",
    "Client secret" : "Bezeroaren Sekretua",
    "API key" : "APIaren gakoa",
    "Public key" : "Gako publikoa",
    "Amazon S3" : "Amazon S3",
    "Hostname" : "Ostalari izena",
    "Port" : "Portua",
    "Region" : "Eskualdea",
    "Enable SSL" : "Gaitu SSL",
    "Enable Path Style" : "Gaitu Bide Estiloa",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Urruneko azpikarpeta",
    "Secure https://" : "https:// segurua",
    "Dropbox" : "Dropbox",
    "Local" : "Bertakoa",
    "Location" : "Kokapena",
    "ownCloud" : "ownCloud",
    "Host" : "Ostalaria",
    "Root" : "Erroa",
    "Share" : "Partekatu",
    "SMB / CIFS using OC login" : "SMB / CIFS saioa hasteko OC erabiliz",
    "Username as share" : "Erabiltzaile izena elkarbanaketa bezala",
    "OpenStack Object Storage" : "OpenStack Objektu Biltegiratzea",
    "<b>Note:</b> " : "<b>Oharra:</b>",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Oharra:</b> :PHPko cURL euskarria ez dago instalatuta edo gaitua. Ezinezko da %s muntatzea. Mesedez eskatu sistema administratzaleari instala dezan. ",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Oharra:</b>\"%s\" euskarria ez dago instalatuta Ezinezko da %s muntatzea. Mesedez eskatu sistema administratzaleari instala dezan. ",
    "No external storage configured" : "Ez da kanpo biltegiratzerik konfiguratu",
    "Name" : "Izena",
    "Storage type" : "Biltegiratze mota",
    "External Storage" : "Kanpoko biltegiratzea",
    "Folder name" : "Karpetaren izena",
    "Configuration" : "Konfigurazioa",
    "Available for" : "Hauentzat eskuragarri",
    "Add storage" : "Gehitu biltegiratzea",
    "Delete" : "Ezabatu",
    "Allow users to mount the following external storage" : "Baimendu erabiltzaileak hurrengo kanpo biltegiratzeak muntatzen"
},
"nplurals=2; plural=(n != 1);");
